# Metrics — Django Developer Reference

Redis-backed time-series metrics with no models or migrations required.

- [Recording Metrics](recording.md) — How to record counters and values
- [Fetching Metrics](fetching.md) — Querying time-series data
- [Permissions](permissions.md) — Per-account permission system, category permissions, REST API
